@@ -5,6 +5,7 @@ import requests
 from progress.bar import Bar
 from progress.spinner import Spinner
 
+from .common import getResponse
 from .web.urls import TASK_STATUS_URL
 
 FAILURE = "FAILURE"
@@ -26,6 +27,7 @@ class Task:
         self.progress = 0
         self.task_state = PENDING
         self.callback = callback
+        self._metrics = {}
         if self.callback:
             t = threading.Thread(target=self.callback_thread)
             t.start()
@@ -56,7 +58,7 @@ class Task:
 
     def callback_thread(self):
         self.get_result()
-        self.callback(self.task_result)
+        self.callback(self)
 
     def get_result(self):
         self.wait()
@@ -66,12 +68,14 @@ class Task:
     def update(self, include_result=False):
         params = {"include_result": include_result}
         response = requests.get(TASK_STATUS_URL + self.task_id, params=params)
-        response = response.json()
+        response = getResponse(response)
         self.task_state = response["state"]
         self.task_type = response["taskType"]
         self.progress = response["progress"]
         if "result" in response:
             self.task_result = response["result"]
+        if "metrics" in response:
+            self._metrics = response["metrics"]
 
     def __str__(self):
         return str(self.get_result())
@@ -80,4 +84,8 @@ class Task:
         self.update()
         return self.task_state in TASK_DONE_LIST
 
+    def metrics(self):
+        self.get_result()
+        return self._metrics
+
 
