@@ -1,10 +1,19 @@
 import glob
+import hashlib
 import tarfile
 import os
+from io import BytesIO
 from tempfile import TemporaryFile
 import numpy as np
 
 
+def convert_to_numpy(data):
+    if isinstance(data, (tuple, list)):
+        return [framework_to_numpy(d) for d in data]
+    else:
+        return framework_to_numpy(data)
+
+
 def save_model(model, library: str):
     model_path = model
     if not isinstance(model, str):
@@ -53,17 +62,64 @@ def save_model(model, library: str):
         # raise ValueError("Tensorflow 1 incompatible. Please use .pb file directly if using Tensorflow 1.")
 
 
-def save_data(data):
-    file = TemporaryFile()
-    if isinstance(data, (tuple, list)):
-        if not all([isinstance(x, np.ndarray) for x in data]):
-            raise TypeError("Either train or validation data is not in numpy array format.")
-        dict_data = {str(i): data[i] for i in range(0, len(data))}
-        np.savez_compressed(file, **dict_data)
+def utf_str(obj):
+    return str(obj).encode("utf-8")
+
+
+def hash_model(model, library):
+    hash = hashlib.md5()
+    if isinstance(model, str):
+        with open(model, "rb") as file:
+            return hashlib.md5(file.read()).hexdigest()
+    elif library == "pytorch":
+        hash.update(utf_str(model))
+        for p in model.parameters():
+            hash.update(utf_str(p))
+    elif library == "mxnet":
+        return ""
+    elif library == "TF":
+        return ""
     else:
-        if not isinstance(data, np.ndarray):
-            raise TypeError("Data is not in numpy array format.")
-        np.savez_compressed(file, data)
+        raise ValueError("Cannot hash... Model type: {} not defined.".format(library))
+    return hash.hexdigest()
+
+
+def framework_to_numpy(data):
+    try:
+        if isinstance(data, np.ndarray):
+            return data
+    finally:
+        pass
+    try:
+        from torch import Tensor
+        if isinstance(data, Tensor):
+            return data.numpy()
+    finally:
+        pass
+    try:
+        import tensorflow
+        # if isinstance(data, data.):
+        if tensorflow.is_tensor(data):
+            return tensorflow.make_ndarray(data)
+    finally:
+        pass
+    try:
+        from mxnet import nd
+        if isinstance(data, nd.NDArray):
+            return data.asnumpy()
+    finally:
+        pass
+    raise ValueError("Could not determine framework data is from. Try pass in numpy array directly.")
+
+
+def save_data(data):
+    file = BytesIO()
+    data = convert_to_numpy(data)
+    if isinstance(data, (tuple, list)):
+        dict_data = {str(i): data[i] for i in range(0, len(data))}
+        np.savez(file, **dict_data)
+    else:
+        np.savez(file, data)
     file.seek(0)
     return file
 
