@@ -1,4 +1,5 @@
-# @wait_task
+import time
+
 import requests
 
 from .Dataset import Dataset
@@ -6,6 +7,8 @@ from .common import getToken, checkData, sliceData
 from .Task import Task
 from .web.urls import TRAIN_URL
 from .Model import Model
+import base64
+import dill
 
 
 def train(model, training_data, test_data, batch_size, epochs, optimiser, loss, asynchronous, callback):
@@ -34,6 +37,9 @@ def trainApi(model_id, train_id, test_id, optimiser, loss, batch_size, epochs, t
     if isinstance(test_id, Dataset):
         test_name = test_id.id
         test_id = ""
+    if callable(loss):
+        print("Using custom loss function...")
+        loss = base64.urlsafe_b64encode(dill.dumps(loss))
     params = {"trainId": train_id, "testId": test_id, "loss": loss,
               "token": getToken(), "batch_size": batch_size, "epochs": epochs, "task_id": task_id, "train_x": train_x,
               "train_y": train_y, "test_x": test_x, "test_y": test_y, "train_name": train_name, "test_name": test_name}
