@@ -10,7 +10,7 @@ def api(token):
     core.api(token)
 
 
-def compile(model, input_shape, library="", model_label="", asynchronous=False):
+def compile(model, input_shape=[], library="", model_label="", asynchronous=False):
     """Use this to upload and compile your model. Compatible frameworks are:
 
         * Pytorch
